import os

from pathlib import Path


def user_config_dir() -> Path:
    """Base directory for user-specific configuration files.

    - Definition: https://specifications.freedesktop.org/basedir-spec/latest/
    - Equivalent: https://pkg.go.dev/os#UserConfigDir
    """
    return _xdg_userdir_for("config")


def user_cache_dir() -> Path:
    """Base directory for user-specific non-essential (cached) data.

    - Definition: https://specifications.freedesktop.org/basedir-spec/latest/
    - Equivalent: https://pkg.go.dev/os#UserCacheDir
    """
    return _xdg_userdir_for("cache")


def _xdg_userdir_for(what: str) -> Path:
    dirname = os.environ.get(f"XDG_{what.upper()}_HOME")
    if dirname:
        return Path(dirname)
    return Path.home() / f".{what}"



from pathlib import Path

import pytest

from hive.common import user_cache_dir, user_config_dir


@pytest.mark.parametrize(
    "func,xdgvar",
    ((user_cache_dir, "XDG_CACHE_HOME"),
     (user_config_dir, "XDG_CONFIG_HOME"),
     ))
def test_with_xdg_var(func, xdgvar, monkeypatch):
    monkeypatch.setenv(xdgvar, "/xdg/magic/beans/")
    assert func() == Path("/xdg/magic/beans")


@pytest.mark.parametrize(
    "func,xdgvar,expect_path",
    ((user_cache_dir, "XDG_CACHE_HOME", Path("/eatme/.cache/")),
     (user_config_dir, "XDG_CONFIG_HOME", Path("/eatme/.config")),
     ))
def test_without_xdg_var(func, xdgvar, monkeypatch, expect_path):
    monkeypatch.delenv(xdgvar, raising=False)
    monkeypatch.setenv("HOME", "/eatme")
    assert func() == expect_path
